AutoArchive._services — AutoArchive Developer Manual (ver. 1.0.4)

# AutoArchive._services

Service Components.

## Sub-Packages

- AutoArchive._services.archiver

## Modules

### service_cleaner

`ServiceCleaner` class.

class `AutoArchive._services.service_cleaner.` `ServiceCleaner`

  Bases: `object`

  Performs clean actions on services.

  static `cleanServices`()

    Puts services to the state before their creation.

    Existing instances of all services will be forgotten. Subsequent request to get or create a service will result in creation of a new instance.